document.addEventListener('DOMContentLoaded', function() {
    function populateTable(data) {
        const tableBody = document.querySelector('tbody');
        tableBody.innerHTML = '';
        Object.entries(data).forEach(([key, value]) => {
            let row = document.createElement('tr');
            row.innerHTML = `<td>${key}</td><td>${value}</td>`;
            tableBody.appendChild(row);
        });
    }
    function addSearchEvent() {
        const searchButton = document.querySelector('button');
        searchButton.addEventListener('click', function() {
            performSearch();
        });
        const input = document.querySelector('input[type="text"]');
        input.addEventListener('keyup', function(event) {
            if (event.key === 'Enter') {
                performSearch();
            }
        });
    }
    function performSearch() {
        const searchText = document.querySelector('input[type="text"]').value;
        fetch('/query', {
            method: 'POST',
            headers: {
                'Content-Type': 'application/json'
            },
            body: JSON.stringify({ path: searchText })
        }).then(response => response.json())
        .then((data) => {
            data = data.result ? data.result : null;
            if(data && data.length > 0) {
                var newData = {};
                newData[searchText] = data[0];
                populateTable(newData);
            }
            else{
                alert('No search not found.');
                return;
            }
            
        }).catch(error => console.error('Error:', error));
    }
    function getTableData() {
        fetch('/data')
         .then(response => response.json())
         .then((data) => {
            populateTable(data);
        })
    }
    function addFloatingImages() {
        var imgCount = Math.floor(Math.random() * 6) + 4;
        var placedPositions = [];
        for (let i = 0; i < imgCount; i++) {
            let topPos, leftPos;
            let isOverlapping = true;
            let attempts = 0;

            while (isOverlapping && attempts < 100) {
                topPos = Math.floor(Math.random() * 80) + "vh";
                leftPos = Math.floor(Math.random() * 80) + "vw";
                isOverlapping = placedPositions.some(pos => {
                    let topDiff = Math.abs(parseInt(pos.top) - parseInt(topPos));
                    let leftDiff = Math.abs(parseInt(pos.left) - parseInt(leftPos));
                    return topDiff < 15 && leftDiff < 15;
                });
                attempts++;
            }
            placedPositions.push({ top: topPos, left: leftPos });
            let animationIndex = Math.floor(Math.random() * 5) + 1;
            let duration = Math.floor(Math.random() * 3) + 10;
            let img = document.createElement('img');
            img.src = `PNG/character${Math.floor(Math.random() * 12) + 1}.png`;
            img.className = 'floating-character';
            img.style.top = topPos;
            img.style.left = leftPos;
            img.style.animation = `float${animationIndex} ${duration}s infinite alternate ease-in-out`;
            document.body.appendChild(img);
        }
    }
    const toggleButton = document.getElementById('toggleAnimations');
    let animationsPaused = false; 
    toggleButton.addEventListener('click', function() {
        const floatingElements = document.querySelectorAll('.floating-character');
        animationsPaused = !animationsPaused; 
        floatingElements.forEach(el => {
            el.style.animationPlayState = animationsPaused ? 'paused' : 'running';
        });

        toggleButton.textContent = animationsPaused ? 'Play Animations' : 'Stop Animations';
    });
    getTableData();
    addSearchEvent();
    addFloatingImages();
});
